summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorßingen <bingen@voltanet.io>2017-07-10 21:14:59 +0200
committerßingen <bingen@voltanet.io>2017-07-10 21:14:59 +0200
commit8e688dbd58fe13ff5b9f444d02b2aa3f046b4d01 (patch)
treebb1a05f62ae77943ec89e5e178385d19b9a0383b /tests
parentFix bug with NH macro in zebra_fpm_protobuf (diff)
downloadfrr-8e688dbd58fe13ff5b9f444d02b2aa3f046b4d01.tar.xz
frr-8e688dbd58fe13ff5b9f444d02b2aa3f046b4d01.zip
Rename ALL_NEXTHOPS_RO to ALL_NEXTHOPS
Diffstat (limited to 'tests')
-rw-r--r--tests/lib/test_nexthop_iter.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/lib/test_nexthop_iter.c b/tests/lib/test_nexthop_iter.c
index 5c5550a64..156249a1c 100644
--- a/tests/lib/test_nexthop_iter.c
+++ b/tests/lib/test_nexthop_iter.c
@@ -1,6 +1,6 @@
/*
* Recursive Nexthop Iterator test.
* This tests the ALL_NEXTHOPS_RO macro.
*
* Copyright (C) 2012 by Open Source Routing.
* Copyright (C) 2012 by Internet Systems Consortium, Inc. ("ISC")
@@ -204,8 +204,8 @@ nexthop_chain_free(struct nexthop_chain *nc)
}
/* This function builds a string representation of
* the nexthop chain using the ALL_NEXTHOPS_RO macro.
* It verifies that the ALL_NEXTHOPS_RO macro iterated
* correctly over the nexthop chain by comparing the
* generated representation with the expected representation.
*/
@@ -215,7 +215,7 @@ nexthop_chain_verify_iter(struct nexthop_chain *nc)
struct nexthop *nh;
char *repr = NULL;
- for (ALL_NEXTHOPS_RO(nc->head, nh))
+ for (ALL_NEXTHOPS(nc->head, nh))
add_string_representation (&repr, nh);
if (repr && verbose)
@@ -1,6 +1,6 @@
/*
* Recursive Nexthop Iterator test.
- * This tests the ALL_NEXTHOPS_RO macro.
+ * This tests the ALL_NEXTHOPS macro.
*
* Copyright (C) 2012 by Open Source Routing.
@@ -204,8 +204,8 @@ nexthop_chain_free(struct nexthop_chain *nc)
}
/* This function builds a string representation of
- * the nexthop chain using the ALL_NEXTHOPS_RO macro.
- * It verifies that the ALL_NEXTHOPS_RO macro iterated
+ * the nexthop chain using the ALL_NEXTHOPS macro.
+ * It verifies that the ALL_NEXTHOPS macro iterated
* correctly over the nexthop chain by comparing the
* generated representation with the expected representation.